/// Extensions for comparable `Iterable`
extension IterableComparableExtension<T extends Comparable> on Iterable<T> {
  /// Returns the element with minimum value.
  ///
  /// If `this` is empty, [StateError] will be thrown.
  T get min {
    if (this.isEmpty) {
      throw StateError('No element');
    }
    return _sorted.first;
  }

  /// Returns the element with maximum value.
  ///
  /// If `this` is empty, [StateError] will be thrown.
  T get max {
    if (this.isEmpty) {
      throw StateError('No element');
    }
    return _sorted.last;
  }

  /// Returns the element with minimum value.
  ///
  /// If `this` is empty, the result of invoking is [null].
  T get minOrNull {
    if (this.isEmpty) {
      return null;
    }
    return _sorted.first;
  }

  /// Returns the element with maximum value.
  ///
  /// If `this` is empty, the result of invoking is [null].
  T get maxOrNull {
    if (this.isEmpty) {
      return null;
    }
    return _sorted.last;
  }

  Iterable<T> get _sorted => this.toList()..sort();
}
