/// Math extensions for numeric `Iterable`
extension IterableMathExtension<T extends num> on Iterable<T> {
  /// Returns the sum of all elements.
  ///
  /// If `this` is empty, the result of invoking is [0].
  num get sum => this.fold<num>(0, (prev, element) => prev + element);

  /// Returns the average of all elements.
  ///
  /// If `this` is empty, the result of invoking is [0].
  num get average => this.isNotEmpty ? sum / this.length : 0;
}
